dot-get_model: Create Formula for Call to Model

Description Usage Arguments Value Examples

Description

Create Formula for Call to Model

Usage

1
.get_model(y, smooth_terms, linear_terms, shape_type)

Arguments

y

- a string of the name of the predictor variable

smooth_terms

- a vector of strings of the names of the spline terms

linear_terms

- a vector of strings of the names of the linear terms

shape_type

- a vector of strings containing the shape constraints for the spline (in the same order as smooth_terms). Can only contain shape constraints that the scam function supports

Value

- string of call to model

Examples

1
2
3
4
5
6
y = "house_price"
smooth_terms = c("sq_ft", "distance_from_work")
linear_terms = c("num_bedrooms", "num_bathrooms")
shape_type = c("mpi", "mpd")

.get_model(y, smooth_terms, linear_terms, shape_type)

christithomp/scamplot documentation built on Dec. 10, 2019, 11:33 a.m.