Description Usage Arguments Value Examples
Create Formula for Call to Model
1 | .get_model(y, smooth_terms, linear_terms, shape_type)
|
y |
- a string of the name of the predictor variable |
smooth_terms |
- a vector of strings of the names of the spline terms |
linear_terms |
- a vector of strings of the names of the linear terms |
shape_type |
- a vector of strings containing the shape constraints for the spline (in the same order as smooth_terms). Can only contain shape constraints that the scam function supports |
- string of call to model
1 2 3 4 5 6 | y = "house_price"
smooth_terms = c("sq_ft", "distance_from_work")
linear_terms = c("num_bedrooms", "num_bathrooms")
shape_type = c("mpi", "mpd")
.get_model(y, smooth_terms, linear_terms, shape_type)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.